"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.offline_user_data_pb2
import google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CreateOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    JOB_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def job(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        job: typing.Optional[
            google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["job", b"job"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "job", b"job"
        ],
    ) -> None: ...

global___CreateOfflineUserDataJobRequest = CreateOfflineUserDataJobRequest

class CreateOfflineUserDataJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___CreateOfflineUserDataJobResponse = CreateOfflineUserDataJobResponse

class GetOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetOfflineUserDataJobRequest = GetOfflineUserDataJobRequest

class RunOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___RunOfflineUserDataJobRequest = RunOfflineUserDataJobRequest

class AddOfflineUserDataJobOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ENABLE_PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def enable_partial_failure(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___OfflineUserDataJobOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        enable_partial_failure: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        operations: typing.Optional[
            typing.Iterable[global___OfflineUserDataJobOperation]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "enable_partial_failure", b"enable_partial_failure"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "enable_partial_failure",
            b"enable_partial_failure",
            "operations",
            b"operations",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___AddOfflineUserDataJobOperationsRequest = AddOfflineUserDataJobOperationsRequest

class OfflineUserDataJobOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    REMOVE_ALL_FIELD_NUMBER: builtins.int
    remove_all: builtins.bool = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    @property
    def remove(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove_all: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove", "remove_all"]: ...

global___OfflineUserDataJobOperation = OfflineUserDataJobOperation

class AddOfflineUserDataJobOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> None: ...

global___AddOfflineUserDataJobOperationsResponse = (
    AddOfflineUserDataJobOperationsResponse
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    @property
    def start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        start_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "end_date", b"end_date", "start_date", b"start_date"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "end_date", b"end_date", "start_date", b"start_date"
        ],
    ) -> None: ...

global___DateRange = DateRange



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_parameter_pb2
import grpc

from .ad_parameter_service_pb2 import *

class AdParameterServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdParameter(
        self,
        request: global___GetAdParameterRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_parameter_pb2.AdParameter: ...
    def MutateAdParameters(
        self,
        request: global___MutateAdParametersRequest,
    ) -> global___MutateAdParametersResponse: ...

class AdParameterServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdParameter(
        self,
        request: global___GetAdParameterRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_parameter_pb2.AdParameter: ...
    @abc.abstractmethod
    def MutateAdParameters(
        self,
        request: global___MutateAdParametersRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdParametersResponse: ...

def add_AdParameterServiceServicer_to_server(
    servicer: AdParameterServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetImpressionShareLocationEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetImpressionShareLocation(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetImpressionShareLocation.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(
            0
        )
        UNKNOWN = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(1)
        ANYWHERE_ON_PAGE = (
            TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(2)
        )
        TOP_OF_PAGE = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(
            3
        )
        ABSOLUTE_TOP_OF_PAGE = (
            TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(4)
        )
    class TargetImpressionShareLocation(metaclass=_TargetImpressionShareLocation):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(0)
    UNKNOWN = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(1)
    ANYWHERE_ON_PAGE = (
        TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(2)
    )
    TOP_OF_PAGE = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(3)
    ABSOLUTE_TOP_OF_PAGE = (
        TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___TargetImpressionShareLocationEnum = TargetImpressionShareLocationEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.google_ads_field_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetGoogleAdsFieldRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetGoogleAdsFieldRequest = GetGoogleAdsFieldRequest

class SearchGoogleAdsFieldsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERY_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    query: typing.Text = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    def __init__(
        self,
        *,
        query: typing.Text = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "page_size", b"page_size", "page_token", b"page_token", "query", b"query"
        ],
    ) -> None: ...

global___SearchGoogleAdsFieldsRequest = SearchGoogleAdsFieldsRequest

class SearchGoogleAdsFieldsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_RESULTS_COUNT_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    total_results_count: builtins.int = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.resources.google_ads_field_pb2.GoogleAdsField
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.resources.google_ads_field_pb2.GoogleAdsField
            ]
        ] = ...,
        next_page_token: typing.Text = ...,
        total_results_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_results_count",
            b"total_results_count",
        ],
    ) -> None: ...

global___SearchGoogleAdsFieldsResponse = SearchGoogleAdsFieldsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_criterion_label_pb2
import grpc

from .ad_group_criterion_label_service_pb2 import *

class AdGroupCriterionLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupCriterionLabel(
        self,
        request: global___GetAdGroupCriterionLabelRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_criterion_label_pb2.AdGroupCriterionLabel: ...
    def MutateAdGroupCriterionLabels(
        self,
        request: global___MutateAdGroupCriterionLabelsRequest,
    ) -> global___MutateAdGroupCriterionLabelsResponse: ...

class AdGroupCriterionLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupCriterionLabel(
        self,
        request: global___GetAdGroupCriterionLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_criterion_label_pb2.AdGroupCriterionLabel: ...
    @abc.abstractmethod
    def MutateAdGroupCriterionLabels(
        self,
        request: global___MutateAdGroupCriterionLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupCriterionLabelsResponse: ...

def add_AdGroupCriterionLabelServiceServicer_to_server(
    servicer: AdGroupCriterionLabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.account_link_pb2
import grpc

from .account_link_service_pb2 import *

class AccountLinkServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAccountLink(
        self,
        request: global___GetAccountLinkRequest,
    ) -> google.ads.google_ads.v4.proto.resources.account_link_pb2.AccountLink: ...
    def MutateAccountLink(
        self,
        request: global___MutateAccountLinkRequest,
    ) -> global___MutateAccountLinkResponse: ...

class AccountLinkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountLink(
        self,
        request: global___GetAccountLinkRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.account_link_pb2.AccountLink: ...
    @abc.abstractmethod
    def MutateAccountLink(
        self,
        request: global___MutateAccountLinkRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAccountLinkResponse: ...

def add_AccountLinkServiceServicer_to_server(
    servicer: AccountLinkServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .user_data_service_pb2 import *

class UserDataServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadUserData(
        self,
        request: global___UploadUserDataRequest,
    ) -> global___UploadUserDataResponse: ...

class UserDataServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadUserData(
        self,
        request: global___UploadUserDataRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadUserDataResponse: ...

def add_UserDataServiceServicer_to_server(
    servicer: UserDataServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(0)
        UNKNOWN = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(1)
        STORE_SALES_UPLOAD_FIRST_PARTY = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(2)
        )
        STORE_SALES_UPLOAD_THIRD_PARTY = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(3)
        )
        CUSTOMER_MATCH_USER_LIST = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(
            4
        )
        CUSTOMER_MATCH_WITH_ATTRIBUTES = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(5)
        )
    class OfflineUserDataJobType(metaclass=_OfflineUserDataJobType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(0)
    UNKNOWN = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(1)
    STORE_SALES_UPLOAD_FIRST_PARTY = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(2)
    )
    STORE_SALES_UPLOAD_THIRD_PARTY = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(3)
    )
    CUSTOMER_MATCH_USER_LIST = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(4)
    CUSTOMER_MATCH_WITH_ATTRIBUTES = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobTypeEnum = OfflineUserDataJobTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FunctionParsingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FunctionParsingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FunctionParsingError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FunctionParsingErrorEnum.FunctionParsingError.V(0)
        UNKNOWN = FunctionParsingErrorEnum.FunctionParsingError.V(1)
        NO_MORE_INPUT = FunctionParsingErrorEnum.FunctionParsingError.V(2)
        EXPECTED_CHARACTER = FunctionParsingErrorEnum.FunctionParsingError.V(3)
        UNEXPECTED_SEPARATOR = FunctionParsingErrorEnum.FunctionParsingError.V(4)
        UNMATCHED_LEFT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(5)
        UNMATCHED_RIGHT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(6)
        TOO_MANY_NESTED_FUNCTIONS = FunctionParsingErrorEnum.FunctionParsingError.V(7)
        MISSING_RIGHT_HAND_OPERAND = FunctionParsingErrorEnum.FunctionParsingError.V(8)
        INVALID_OPERATOR_NAME = FunctionParsingErrorEnum.FunctionParsingError.V(9)
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = (
            FunctionParsingErrorEnum.FunctionParsingError.V(10)
        )
        NO_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(11)
        TOO_MANY_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(12)
    class FunctionParsingError(metaclass=_FunctionParsingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FunctionParsingErrorEnum.FunctionParsingError.V(0)
    UNKNOWN = FunctionParsingErrorEnum.FunctionParsingError.V(1)
    NO_MORE_INPUT = FunctionParsingErrorEnum.FunctionParsingError.V(2)
    EXPECTED_CHARACTER = FunctionParsingErrorEnum.FunctionParsingError.V(3)
    UNEXPECTED_SEPARATOR = FunctionParsingErrorEnum.FunctionParsingError.V(4)
    UNMATCHED_LEFT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(5)
    UNMATCHED_RIGHT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(6)
    TOO_MANY_NESTED_FUNCTIONS = FunctionParsingErrorEnum.FunctionParsingError.V(7)
    MISSING_RIGHT_HAND_OPERAND = FunctionParsingErrorEnum.FunctionParsingError.V(8)
    INVALID_OPERATOR_NAME = FunctionParsingErrorEnum.FunctionParsingError.V(9)
    FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = (
        FunctionParsingErrorEnum.FunctionParsingError.V(10)
    )
    NO_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(11)
    TOO_MANY_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(12)
    def __init__(
        self,
    ) -> None: ...

global___FunctionParsingErrorEnum = FunctionParsingErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2
import grpc

from .campaign_shared_set_service_pb2 import *

class CampaignSharedSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignSharedSet(
        self,
        request: global___GetCampaignSharedSetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2.CampaignSharedSet: ...
    def MutateCampaignSharedSets(
        self,
        request: global___MutateCampaignSharedSetsRequest,
    ) -> global___MutateCampaignSharedSetsResponse: ...

class CampaignSharedSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignSharedSet(
        self,
        request: global___GetCampaignSharedSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2.CampaignSharedSet: ...
    @abc.abstractmethod
    def MutateCampaignSharedSets(
        self,
        request: global___MutateCampaignSharedSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignSharedSetsResponse: ...

def add_CampaignSharedSetServiceServicer_to_server(
    servicer: CampaignSharedSetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanNetworkEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanNetwork(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            KeywordPlanNetwork.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(0)
        UNKNOWN = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(1)
        GOOGLE_SEARCH = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(2)
        GOOGLE_SEARCH_AND_PARTNERS = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(3)
    class KeywordPlanNetwork(metaclass=_KeywordPlanNetwork):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(0)
    UNKNOWN = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(1)
    GOOGLE_SEARCH = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(2)
    GOOGLE_SEARCH_AND_PARTNERS = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(3)
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanNetworkEnum = KeywordPlanNetworkEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.manager_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClientLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    MANAGER_LINK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.manager_link_status_pb2.ManagerLinkStatusEnum.ManagerLinkStatus.V = (
        ...
    )
    @property
    def client_customer(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def manager_link_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def hidden(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        manager_link_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        status: google.ads.google_ads.v4.proto.enums.manager_link_status_pb2.ManagerLinkStatusEnum.ManagerLinkStatus.V = ...,
        hidden: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "hidden",
            b"hidden",
            "manager_link_id",
            b"manager_link_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "hidden",
            b"hidden",
            "manager_link_id",
            b"manager_link_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

global___CustomerClientLink = CustomerClientLink



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ManagerLinkStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ManagerLinkStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ManagerLinkStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ManagerLinkStatusEnum.ManagerLinkStatus.V(0)
        UNKNOWN = ManagerLinkStatusEnum.ManagerLinkStatus.V(1)
        ACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(2)
        INACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(3)
        PENDING = ManagerLinkStatusEnum.ManagerLinkStatus.V(4)
        REFUSED = ManagerLinkStatusEnum.ManagerLinkStatus.V(5)
        CANCELED = ManagerLinkStatusEnum.ManagerLinkStatus.V(6)
    class ManagerLinkStatus(metaclass=_ManagerLinkStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ManagerLinkStatusEnum.ManagerLinkStatus.V(0)
    UNKNOWN = ManagerLinkStatusEnum.ManagerLinkStatus.V(1)
    ACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(2)
    INACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(3)
    PENDING = ManagerLinkStatusEnum.ManagerLinkStatus.V(4)
    REFUSED = ManagerLinkStatusEnum.ManagerLinkStatus.V(5)
    CANCELED = ManagerLinkStatusEnum.ManagerLinkStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ManagerLinkStatusEnum = ManagerLinkStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2
import google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2
import google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = (
        ...
    )
    type: google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def description(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def members(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CustomInterestMember
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        status: google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        type: google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = ...,
        description: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        members: typing.Optional[typing.Iterable[global___CustomInterestMember]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "description", b"description", "id", b"id", "name", b"name"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "description",
            b"description",
            "id",
            b"id",
            "members",
            b"members",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CustomInterest = CustomInterest

class CustomInterestMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEMBER_TYPE_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    member_type: google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = (
        ...
    )
    @property
    def parameter(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        member_type: google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = ...,
        parameter: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["parameter", b"parameter"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "member_type", b"member_type", "parameter", b"parameter"
        ],
    ) -> None: ...

global___CustomInterestMember = CustomInterestMember



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FieldMaskErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FieldMaskError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FieldMaskError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FieldMaskErrorEnum.FieldMaskError.V(0)
        UNKNOWN = FieldMaskErrorEnum.FieldMaskError.V(1)
        FIELD_MASK_MISSING = FieldMaskErrorEnum.FieldMaskError.V(5)
        FIELD_MASK_NOT_ALLOWED = FieldMaskErrorEnum.FieldMaskError.V(4)
        FIELD_NOT_FOUND = FieldMaskErrorEnum.FieldMaskError.V(2)
        FIELD_HAS_SUBFIELDS = FieldMaskErrorEnum.FieldMaskError.V(3)
    class FieldMaskError(metaclass=_FieldMaskError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FieldMaskErrorEnum.FieldMaskError.V(0)
    UNKNOWN = FieldMaskErrorEnum.FieldMaskError.V(1)
    FIELD_MASK_MISSING = FieldMaskErrorEnum.FieldMaskError.V(5)
    FIELD_MASK_NOT_ALLOWED = FieldMaskErrorEnum.FieldMaskError.V(4)
    FIELD_NOT_FOUND = FieldMaskErrorEnum.FieldMaskError.V(2)
    FIELD_HAS_SUBFIELDS = FieldMaskErrorEnum.FieldMaskError.V(3)
    def __init__(
        self,
    ) -> None: ...

global___FieldMaskErrorEnum = FieldMaskErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DatabaseErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DatabaseError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DatabaseError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DatabaseErrorEnum.DatabaseError.V(0)
        UNKNOWN = DatabaseErrorEnum.DatabaseError.V(1)
        CONCURRENT_MODIFICATION = DatabaseErrorEnum.DatabaseError.V(2)
        DATA_CONSTRAINT_VIOLATION = DatabaseErrorEnum.DatabaseError.V(3)
        REQUEST_TOO_LARGE = DatabaseErrorEnum.DatabaseError.V(4)
    class DatabaseError(metaclass=_DatabaseError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DatabaseErrorEnum.DatabaseError.V(0)
    UNKNOWN = DatabaseErrorEnum.DatabaseError.V(1)
    CONCURRENT_MODIFICATION = DatabaseErrorEnum.DatabaseError.V(2)
    DATA_CONSTRAINT_VIOLATION = DatabaseErrorEnum.DatabaseError.V(3)
    REQUEST_TOO_LARGE = DatabaseErrorEnum.DatabaseError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___DatabaseErrorEnum = DatabaseErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.keyword_plan_campaign_pb2
import grpc

from .keyword_plan_campaign_service_pb2 import *

class KeywordPlanCampaignServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanCampaign(
        self,
        request: global___GetKeywordPlanCampaignRequest,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_campaign_pb2.KeywordPlanCampaign: ...
    def MutateKeywordPlanCampaigns(
        self,
        request: global___MutateKeywordPlanCampaignsRequest,
    ) -> global___MutateKeywordPlanCampaignsResponse: ...

class KeywordPlanCampaignServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanCampaign(
        self,
        request: global___GetKeywordPlanCampaignRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_campaign_pb2.KeywordPlanCampaign: ...
    @abc.abstractmethod
    def MutateKeywordPlanCampaigns(
        self,
        request: global___MutateKeywordPlanCampaignsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanCampaignsResponse: ...

def add_KeywordPlanCampaignServiceServicer_to_server(
    servicer: KeywordPlanCampaignServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExternalConversionSourceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExternalConversionSource(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExternalConversionSource.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(0)
        UNKNOWN = ExternalConversionSourceEnum.ExternalConversionSource.V(1)
        WEBPAGE = ExternalConversionSourceEnum.ExternalConversionSource.V(2)
        ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(3)
        UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(4)
        AD_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(5)
        WEBSITE_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(
            6
        )
        STORE_VISITS = ExternalConversionSourceEnum.ExternalConversionSource.V(7)
        ANDROID_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(8)
        IOS_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(9)
        IOS_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(10)
        APP_UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(11)
        ANDROID_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(12)
        UPLOAD_CALLS = ExternalConversionSourceEnum.ExternalConversionSource.V(13)
        FIREBASE = ExternalConversionSourceEnum.ExternalConversionSource.V(14)
        CLICK_TO_CALL = ExternalConversionSourceEnum.ExternalConversionSource.V(15)
        SALESFORCE = ExternalConversionSourceEnum.ExternalConversionSource.V(16)
        STORE_SALES_CRM = ExternalConversionSourceEnum.ExternalConversionSource.V(17)
        STORE_SALES_PAYMENT_NETWORK = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(18)
        )
        GOOGLE_PLAY = ExternalConversionSourceEnum.ExternalConversionSource.V(19)
        THIRD_PARTY_APP_ANALYTICS = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(20)
        )
        GOOGLE_ATTRIBUTION = ExternalConversionSourceEnum.ExternalConversionSource.V(21)
        STORE_SALES_DIRECT_UPLOAD = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(23)
        )
        STORE_SALES = ExternalConversionSourceEnum.ExternalConversionSource.V(24)
        SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(25)
        GOOGLE_HOSTED = ExternalConversionSourceEnum.ExternalConversionSource.V(27)
        FLOODLIGHT = ExternalConversionSourceEnum.ExternalConversionSource.V(29)
        ANALYTICS_SEARCH_ADS_360 = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(31)
        )
    class ExternalConversionSource(metaclass=_ExternalConversionSource):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(0)
    UNKNOWN = ExternalConversionSourceEnum.ExternalConversionSource.V(1)
    WEBPAGE = ExternalConversionSourceEnum.ExternalConversionSource.V(2)
    ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(3)
    UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(4)
    AD_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(5)
    WEBSITE_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(6)
    STORE_VISITS = ExternalConversionSourceEnum.ExternalConversionSource.V(7)
    ANDROID_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(8)
    IOS_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(9)
    IOS_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(10)
    APP_UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(11)
    ANDROID_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(12)
    UPLOAD_CALLS = ExternalConversionSourceEnum.ExternalConversionSource.V(13)
    FIREBASE = ExternalConversionSourceEnum.ExternalConversionSource.V(14)
    CLICK_TO_CALL = ExternalConversionSourceEnum.ExternalConversionSource.V(15)
    SALESFORCE = ExternalConversionSourceEnum.ExternalConversionSource.V(16)
    STORE_SALES_CRM = ExternalConversionSourceEnum.ExternalConversionSource.V(17)
    STORE_SALES_PAYMENT_NETWORK = (
        ExternalConversionSourceEnum.ExternalConversionSource.V(18)
    )
    GOOGLE_PLAY = ExternalConversionSourceEnum.ExternalConversionSource.V(19)
    THIRD_PARTY_APP_ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(
        20
    )
    GOOGLE_ATTRIBUTION = ExternalConversionSourceEnum.ExternalConversionSource.V(21)
    STORE_SALES_DIRECT_UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(
        23
    )
    STORE_SALES = ExternalConversionSourceEnum.ExternalConversionSource.V(24)
    SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(25)
    GOOGLE_HOSTED = ExternalConversionSourceEnum.ExternalConversionSource.V(27)
    FLOODLIGHT = ExternalConversionSourceEnum.ExternalConversionSource.V(29)
    ANALYTICS_SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(
        31
    )
    def __init__(
        self,
    ) -> None: ...

global___ExternalConversionSourceEnum = ExternalConversionSourceEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignFeedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignFeedErrorEnum.CampaignFeedError.V(0)
        UNKNOWN = CampaignFeedErrorEnum.CampaignFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            CampaignFeedErrorEnum.CampaignFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(4)
        CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED = (
            CampaignFeedErrorEnum.CampaignFeedError.V(5)
        )
        CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(
            6
        )
        INVALID_PLACEHOLDER_TYPE = CampaignFeedErrorEnum.CampaignFeedError.V(7)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            CampaignFeedErrorEnum.CampaignFeedError.V(8)
        )
        NO_EXISTING_LOCATION_CUSTOMER_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(
            9
        )
    class CampaignFeedError(metaclass=_CampaignFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignFeedErrorEnum.CampaignFeedError.V(0)
    UNKNOWN = CampaignFeedErrorEnum.CampaignFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        CampaignFeedErrorEnum.CampaignFeedError.V(2)
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(4)
    CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED = (
        CampaignFeedErrorEnum.CampaignFeedError.V(5)
    )
    CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(6)
    INVALID_PLACEHOLDER_TYPE = CampaignFeedErrorEnum.CampaignFeedError.V(7)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
        CampaignFeedErrorEnum.CampaignFeedError.V(8)
    )
    NO_EXISTING_LOCATION_CUSTOMER_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___CampaignFeedErrorEnum = CampaignFeedErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CurrencyConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYMBOL_FIELD_NUMBER: builtins.int
    BILLABLE_UNIT_MICROS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    code: typing.Text = ...
    name: typing.Text = ...
    symbol: typing.Text = ...
    billable_unit_micros: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        code: typing.Text = ...,
        name: typing.Text = ...,
        symbol: typing.Text = ...,
        billable_unit_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "symbol",
            b"symbol",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "symbol",
            b"symbol",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_billable_unit_micros", b"_billable_unit_micros"
        ],
    ) -> typing_extensions.Literal["billable_unit_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_code", b"_code"]
    ) -> typing_extensions.Literal["code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_symbol", b"_symbol"]
    ) -> typing_extensions.Literal["symbol"]: ...

global___CurrencyConstant = CurrencyConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QuotaErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QuotaError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QuotaErrorEnum.QuotaError.V(0)
        UNKNOWN = QuotaErrorEnum.QuotaError.V(1)
        RESOURCE_EXHAUSTED = QuotaErrorEnum.QuotaError.V(2)
        ACCESS_PROHIBITED = QuotaErrorEnum.QuotaError.V(3)
        RESOURCE_TEMPORARILY_EXHAUSTED = QuotaErrorEnum.QuotaError.V(4)
    class QuotaError(metaclass=_QuotaError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QuotaErrorEnum.QuotaError.V(0)
    UNKNOWN = QuotaErrorEnum.QuotaError.V(1)
    RESOURCE_EXHAUSTED = QuotaErrorEnum.QuotaError.V(2)
    ACCESS_PROHIBITED = QuotaErrorEnum.QuotaError.V(3)
    RESOURCE_TEMPORARILY_EXHAUSTED = QuotaErrorEnum.QuotaError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___QuotaErrorEnum = QuotaErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KeywordPlanError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = KeywordPlanErrorEnum.KeywordPlanError.V(0)
        UNKNOWN = KeywordPlanErrorEnum.KeywordPlanError.V(1)
        BID_MULTIPLIER_OUT_OF_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(2)
        BID_TOO_HIGH = KeywordPlanErrorEnum.KeywordPlanError.V(3)
        BID_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(4)
        BID_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(5)
        DAILY_BUDGET_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(6)
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = (
            KeywordPlanErrorEnum.KeywordPlanError.V(7)
        )
        INVALID_VALUE = KeywordPlanErrorEnum.KeywordPlanError.V(8)
        KEYWORD_PLAN_HAS_NO_KEYWORDS = KeywordPlanErrorEnum.KeywordPlanError.V(9)
        KEYWORD_PLAN_NOT_ENABLED = KeywordPlanErrorEnum.KeywordPlanError.V(10)
        KEYWORD_PLAN_NOT_FOUND = KeywordPlanErrorEnum.KeywordPlanError.V(11)
        MISSING_BID = KeywordPlanErrorEnum.KeywordPlanError.V(13)
        MISSING_FORECAST_PERIOD = KeywordPlanErrorEnum.KeywordPlanError.V(14)
        INVALID_FORECAST_DATE_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(15)
        INVALID_NAME = KeywordPlanErrorEnum.KeywordPlanError.V(16)
    class KeywordPlanError(metaclass=_KeywordPlanError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanErrorEnum.KeywordPlanError.V(0)
    UNKNOWN = KeywordPlanErrorEnum.KeywordPlanError.V(1)
    BID_MULTIPLIER_OUT_OF_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(2)
    BID_TOO_HIGH = KeywordPlanErrorEnum.KeywordPlanError.V(3)
    BID_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(4)
    BID_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(5)
    DAILY_BUDGET_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(6)
    DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(7)
    INVALID_VALUE = KeywordPlanErrorEnum.KeywordPlanError.V(8)
    KEYWORD_PLAN_HAS_NO_KEYWORDS = KeywordPlanErrorEnum.KeywordPlanError.V(9)
    KEYWORD_PLAN_NOT_ENABLED = KeywordPlanErrorEnum.KeywordPlanError.V(10)
    KEYWORD_PLAN_NOT_FOUND = KeywordPlanErrorEnum.KeywordPlanError.V(11)
    MISSING_BID = KeywordPlanErrorEnum.KeywordPlanError.V(13)
    MISSING_FORECAST_PERIOD = KeywordPlanErrorEnum.KeywordPlanError.V(14)
    INVALID_FORECAST_DATE_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(15)
    INVALID_NAME = KeywordPlanErrorEnum.KeywordPlanError.V(16)
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanErrorEnum = KeywordPlanErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.shared_set_pb2
import grpc

from .shared_set_service_pb2 import *

class SharedSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetSharedSet(
        self,
        request: global___GetSharedSetRequest,
    ) -> google.ads.google_ads.v5.proto.resources.shared_set_pb2.SharedSet: ...
    def MutateSharedSets(
        self,
        request: global___MutateSharedSetsRequest,
    ) -> global___MutateSharedSetsResponse: ...

class SharedSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSharedSet(
        self,
        request: global___GetSharedSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.shared_set_pb2.SharedSet: ...
    @abc.abstractmethod
    def MutateSharedSets(
        self,
        request: global___MutateSharedSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateSharedSetsResponse: ...

def add_SharedSetServiceServicer_to_server(
    servicer: SharedSetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_RESTRICTIONS_FIELD_NUMBER: builtins.int
    TARGET_RESTRICTION_OPERATIONS_FIELD_NUMBER: builtins.int
    @property
    def target_restrictions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetRestriction
    ]: ...
    @property
    def target_restriction_operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetRestrictionOperation
    ]: ...
    def __init__(
        self,
        *,
        target_restrictions: typing.Optional[
            typing.Iterable[global___TargetRestriction]
        ] = ...,
        target_restriction_operations: typing.Optional[
            typing.Iterable[global___TargetRestrictionOperation]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "target_restriction_operations",
            b"target_restriction_operations",
            "target_restrictions",
            b"target_restrictions",
        ],
    ) -> None: ...

global___TargetingSetting = TargetingSetting

class TargetRestriction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGETING_DIMENSION_FIELD_NUMBER: builtins.int
    BID_ONLY_FIELD_NUMBER: builtins.int
    targeting_dimension: google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2.TargetingDimensionEnum.TargetingDimension.V = (
        ...
    )
    bid_only: builtins.bool = ...
    def __init__(
        self,
        *,
        targeting_dimension: google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2.TargetingDimensionEnum.TargetingDimension.V = ...,
        bid_only: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_only", b"_bid_only", "bid_only", b"bid_only"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_only",
            b"_bid_only",
            "bid_only",
            b"bid_only",
            "targeting_dimension",
            b"targeting_dimension",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_only", b"_bid_only"]
    ) -> typing_extensions.Literal["bid_only"]: ...

global___TargetRestriction = TargetRestriction

class TargetRestrictionOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Operator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Operator.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TargetRestrictionOperation.Operator.V(0)
        UNKNOWN = TargetRestrictionOperation.Operator.V(1)
        ADD = TargetRestrictionOperation.Operator.V(2)
        REMOVE = TargetRestrictionOperation.Operator.V(3)
    class Operator(metaclass=_Operator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TargetRestrictionOperation.Operator.V(0)
    UNKNOWN = TargetRestrictionOperation.Operator.V(1)
    ADD = TargetRestrictionOperation.Operator.V(2)
    REMOVE = TargetRestrictionOperation.Operator.V(3)

    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    operator: global___TargetRestrictionOperation.Operator.V = ...
    @property
    def value(self) -> global___TargetRestriction: ...
    def __init__(
        self,
        *,
        operator: global___TargetRestrictionOperation.Operator.V = ...,
        value: typing.Optional[global___TargetRestriction] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["value", b"value"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

global___TargetRestrictionOperation = TargetRestrictionOperation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.customer_client_pb2
import grpc

from .customer_client_service_pb2 import *

class CustomerClientServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerClient(
        self,
        request: global___GetCustomerClientRequest,
    ) -> google.ads.google_ads.v5.proto.resources.customer_client_pb2.CustomerClient: ...

class CustomerClientServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerClient(
        self,
        request: global___GetCustomerClientRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.customer_client_pb2.CustomerClient: ...

def add_CustomerClientServiceServicer_to_server(
    servicer: CustomerClientServiceServicer, server: grpc.Server
) -> None: ...



from typing import (
    Any,
    Callable,
    ClassVar,
    Dict,
    Iterable,
    List,
    Optional,
    Sequence,
    Tuple,
    Union,
)

import grpc
from google.api_core.client_options import ClientOptions  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from google.auth.credentials import Credentials  # type: ignore
from google.oauth2 import service_account as service_account  # type: ignore

from google.ads.google_ads.v5.proto.services import (
    keyword_plan_idea_service_pb2 as keyword_plan_idea_service_pb2,
)
from google.ads.google_ads.v5.services import (
    keyword_plan_idea_service_client_config as keyword_plan_idea_service_client_config,
)
from google.ads.google_ads.v5.services.transports import (
    keyword_plan_idea_service_grpc_transport as keyword_plan_idea_service_grpc_transport,
)
from google.ads.google_ads.v5.types import (
    GenerateKeywordIdeaResult,
    KeywordAndUrlSeed,
    KeywordPlanNetworkEnum,
    KeywordSeed,
    SiteSeed,
    StringValue,
    UrlSeed,
)

class KeywordPlanIdeaServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> KeywordPlanIdeaServiceClient: ...
    @classmethod
    def from_service_account_json(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> KeywordPlanIdeaServiceClient: ...
    transport: Union[
        keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport,
        Callable[
            [Credentials, type],
            keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport,
        ],
    ] = ...
    def __init__(
        self,
        transport: Optional[
            Union[
                keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport,
                Callable[
                    [Credentials, type],
                    keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport,
                ],
            ]
        ] = ...,
        channel: Optional[grpc.Channel] = ...,
        credentials: Optional[Credentials] = ...,
        client_config: Optional[Dict[str, Any]] = ...,
        client_info: Optional[ClientInfo] = ...,
        client_options: Optional[Union[Dict[str, Any], ClientOptions]] = ...,
    ) -> None: ...
    def generate_keyword_ideas(
        self,
        customer_id: str,
        language: Union[Dict[str, Any], StringValue],
        geo_target_constants: List[Union[Dict[str, Any], StringValue]],
        include_adult_keywords: bool,
        keyword_plan_network: KeywordPlanNetworkEnum.KeywordPlanNetwork.V,
        page_size: Optional[int] = ...,
        keyword_and_url_seed: Optional[Union[Dict[str, Any], KeywordAndUrlSeed]] = ...,
        keyword_seed: Optional[Union[Dict[str, Any], KeywordSeed]] = ...,
        url_seed: Optional[Union[Dict[str, Any], UrlSeed]] = ...,
        site_seed: Optional[Union[Dict[str, Any], SiteSeed]] = ...,
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> Iterable[GenerateKeywordIdeaResult]: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.month_of_year_pb2
import google.ads.google_ads.v4.proto.resources.invoice_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListInvoicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    ISSUE_YEAR_FIELD_NUMBER: builtins.int
    ISSUE_MONTH_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    billing_setup: typing.Text = ...
    issue_year: typing.Text = ...
    issue_month: google.ads.google_ads.v4.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        billing_setup: typing.Text = ...,
        issue_year: typing.Text = ...,
        issue_month: google.ads.google_ads.v4.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "billing_setup",
            b"billing_setup",
            "customer_id",
            b"customer_id",
            "issue_month",
            b"issue_month",
            "issue_year",
            b"issue_year",
        ],
    ) -> None: ...

global___ListInvoicesRequest = ListInvoicesRequest

class ListInvoicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INVOICES_FIELD_NUMBER: builtins.int
    @property
    def invoices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.resources.invoice_pb2.Invoice
    ]: ...
    def __init__(
        self,
        *,
        invoices: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.resources.invoice_pb2.Invoice
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["invoices", b"invoices"]
    ) -> None: ...

global___ListInvoicesResponse = ListInvoicesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            HotelPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(0)
        UNKNOWN = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(1)
        PROPERTY_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(2)
        PROPERTY_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(3)
        DESTINATION_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(4)
        DESCRIPTION = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(5)
        ADDRESS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(6)
        PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(7)
        FORMATTED_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(8)
        SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(10)
        IMAGE_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(11)
        CATEGORY = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(12)
        STAR_RATING = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(13)
        CONTEXTUAL_KEYWORDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(14)
        FINAL_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(15)
        FINAL_MOBILE_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(16)
        TRACKING_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(17)
        ANDROID_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(18)
        SIMILAR_PROPERTY_IDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(19)
        IOS_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(20)
        IOS_APP_STORE_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(21)
    class HotelPlaceholderField(metaclass=_HotelPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(0)
    UNKNOWN = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(1)
    PROPERTY_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(2)
    PROPERTY_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(3)
    DESTINATION_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(4)
    DESCRIPTION = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(5)
    ADDRESS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(6)
    PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(7)
    FORMATTED_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(8)
    SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(10)
    IMAGE_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(11)
    CATEGORY = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(12)
    STAR_RATING = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(13)
    CONTEXTUAL_KEYWORDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(14)
    FINAL_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(15)
    FINAL_MOBILE_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(16)
    TRACKING_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(17)
    ANDROID_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(18)
    SIMILAR_PROPERTY_IDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(19)
    IOS_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(20)
    IOS_APP_STORE_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___HotelPlaceholderFieldEnum = HotelPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeoTargetingTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GeoTargetingType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GeoTargetingType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = GeoTargetingTypeEnum.GeoTargetingType.V(0)
        UNKNOWN = GeoTargetingTypeEnum.GeoTargetingType.V(1)
        AREA_OF_INTEREST = GeoTargetingTypeEnum.GeoTargetingType.V(2)
        LOCATION_OF_PRESENCE = GeoTargetingTypeEnum.GeoTargetingType.V(3)
    class GeoTargetingType(metaclass=_GeoTargetingType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = GeoTargetingTypeEnum.GeoTargetingType.V(0)
    UNKNOWN = GeoTargetingTypeEnum.GeoTargetingType.V(1)
    AREA_OF_INTEREST = GeoTargetingTypeEnum.GeoTargetingType.V(2)
    LOCATION_OF_PRESENCE = GeoTargetingTypeEnum.GeoTargetingType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___GeoTargetingTypeEnum = GeoTargetingTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.placeholder_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedPlaceholderView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placeholder_type: google.ads.google_ads.v4.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placeholder_type: google.ads.google_ads.v4.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "placeholder_type", b"placeholder_type", "resource_name", b"resource_name"
        ],
    ) -> None: ...

global___FeedPlaceholderView = FeedPlaceholderView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyTopicEntryTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyTopicEntryType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyTopicEntryType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(0)
        UNKNOWN = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(1)
        PROHIBITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(2)
        LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(4)
        FULLY_LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(8)
        DESCRIPTIVE = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(5)
        BROADENING = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(6)
        AREA_OF_INTEREST_ONLY = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(7)
    class PolicyTopicEntryType(metaclass=_PolicyTopicEntryType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(0)
    UNKNOWN = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(1)
    PROHIBITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(2)
    LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(4)
    FULLY_LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(8)
    DESCRIPTIVE = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(5)
    BROADENING = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(6)
    AREA_OF_INTEREST_ONLY = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PolicyTopicEntryTypeEnum = PolicyTopicEntryTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    start_date: typing.Text = ...
    end_date: typing.Text = ...
    def __init__(
        self,
        *,
        start_date: typing.Text = ...,
        end_date: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_end_date", b"_end_date"]
    ) -> typing_extensions.Literal["end_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_date", b"_start_date"]
    ) -> typing_extensions.Literal["start_date"]: ...

global___DateRange = DateRange



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemSetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedItemSetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemSetErrorEnum.FeedItemSetError.V(0)
        UNKNOWN = FeedItemSetErrorEnum.FeedItemSetError.V(1)
        FEED_ITEM_SET_REMOVED = FeedItemSetErrorEnum.FeedItemSetError.V(2)
        CANNOT_CLEAR_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(3)
        CANNOT_CREATE_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(4)
        INVALID_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(5)
        DUPLICATE_NAME = FeedItemSetErrorEnum.FeedItemSetError.V(6)
        WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(7)
    class FeedItemSetError(metaclass=_FeedItemSetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemSetErrorEnum.FeedItemSetError.V(0)
    UNKNOWN = FeedItemSetErrorEnum.FeedItemSetError.V(1)
    FEED_ITEM_SET_REMOVED = FeedItemSetErrorEnum.FeedItemSetError.V(2)
    CANNOT_CLEAR_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(3)
    CANNOT_CREATE_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(4)
    INVALID_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(5)
    DUPLICATE_NAME = FeedItemSetErrorEnum.FeedItemSetError.V(6)
    WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemSetErrorEnum = FeedItemSetErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionErrorEnum.ConversionActionError.V(0)
        UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(1)
        DUPLICATE_NAME = ConversionActionErrorEnum.ConversionActionError.V(2)
        DUPLICATE_APP_ID = ConversionActionErrorEnum.ConversionActionError.V(3)
        TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = (
            ConversionActionErrorEnum.ConversionActionError.V(4)
        )
        BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = (
            ConversionActionErrorEnum.ConversionActionError.V(5)
        )
        DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = (
            ConversionActionErrorEnum.ConversionActionError.V(6)
        )
        DATA_DRIVEN_MODEL_EXPIRED = ConversionActionErrorEnum.ConversionActionError.V(7)
        DATA_DRIVEN_MODEL_STALE = ConversionActionErrorEnum.ConversionActionError.V(8)
        DATA_DRIVEN_MODEL_UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(9)
        CREATION_NOT_SUPPORTED = ConversionActionErrorEnum.ConversionActionError.V(10)
    class ConversionActionError(metaclass=_ConversionActionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionErrorEnum.ConversionActionError.V(0)
    UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(1)
    DUPLICATE_NAME = ConversionActionErrorEnum.ConversionActionError.V(2)
    DUPLICATE_APP_ID = ConversionActionErrorEnum.ConversionActionError.V(3)
    TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = (
        ConversionActionErrorEnum.ConversionActionError.V(4)
    )
    BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = (
        ConversionActionErrorEnum.ConversionActionError.V(5)
    )
    DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = (
        ConversionActionErrorEnum.ConversionActionError.V(6)
    )
    DATA_DRIVEN_MODEL_EXPIRED = ConversionActionErrorEnum.ConversionActionError.V(7)
    DATA_DRIVEN_MODEL_STALE = ConversionActionErrorEnum.ConversionActionError.V(8)
    DATA_DRIVEN_MODEL_UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(9)
    CREATION_NOT_SUPPORTED = ConversionActionErrorEnum.ConversionActionError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionErrorEnum = ConversionActionErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateRangeErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DateRangeError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DateRangeError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DateRangeErrorEnum.DateRangeError.V(0)
        UNKNOWN = DateRangeErrorEnum.DateRangeError.V(1)
        INVALID_DATE = DateRangeErrorEnum.DateRangeError.V(2)
        START_DATE_AFTER_END_DATE = DateRangeErrorEnum.DateRangeError.V(3)
        CANNOT_SET_DATE_TO_PAST = DateRangeErrorEnum.DateRangeError.V(4)
        AFTER_MAXIMUM_ALLOWABLE_DATE = DateRangeErrorEnum.DateRangeError.V(5)
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = (
            DateRangeErrorEnum.DateRangeError.V(6)
        )
    class DateRangeError(metaclass=_DateRangeError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DateRangeErrorEnum.DateRangeError.V(0)
    UNKNOWN = DateRangeErrorEnum.DateRangeError.V(1)
    INVALID_DATE = DateRangeErrorEnum.DateRangeError.V(2)
    START_DATE_AFTER_END_DATE = DateRangeErrorEnum.DateRangeError.V(3)
    CANNOT_SET_DATE_TO_PAST = DateRangeErrorEnum.DateRangeError.V(4)
    AFTER_MAXIMUM_ALLOWABLE_DATE = DateRangeErrorEnum.DateRangeError.V(5)
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = DateRangeErrorEnum.DateRangeError.V(6)
    def __init__(
        self,
    ) -> None: ...

global___DateRangeErrorEnum = DateRangeErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2
import grpc

from .ad_group_feed_service_pb2 import *

class AdGroupFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupFeed(
        self,
        request: global___GetAdGroupFeedRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
    def MutateAdGroupFeeds(
        self,
        request: global___MutateAdGroupFeedsRequest,
    ) -> global___MutateAdGroupFeedsResponse: ...

class AdGroupFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupFeed(
        self,
        request: global___GetAdGroupFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
    @abc.abstractmethod
    def MutateAdGroupFeeds(
        self,
        request: global___MutateAdGroupFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupFeedsResponse: ...

def add_AdGroupFeedServiceServicer_to_server(
    servicer: AdGroupFeedServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_feed_pb2
import grpc

from .customer_feed_service_pb2 import *

class CustomerFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerFeed(
        self,
        request: global___GetCustomerFeedRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed: ...
    def MutateCustomerFeeds(
        self,
        request: global___MutateCustomerFeedsRequest,
    ) -> global___MutateCustomerFeedsResponse: ...

class CustomerFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerFeed(
        self,
        request: global___GetCustomerFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed: ...
    @abc.abstractmethod
    def MutateCustomerFeeds(
        self,
        request: global___MutateCustomerFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerFeedsResponse: ...

def add_CustomerFeedServiceServicer_to_server(
    servicer: CustomerFeedServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_pb2
import grpc

from .ad_service_pb2 import *

class AdServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAd(
        self,
        request: global___GetAdRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    def MutateAds(
        self,
        request: global___MutateAdsRequest,
    ) -> global___MutateAdsResponse: ...

class AdServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAd(
        self,
        request: global___GetAdRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    @abc.abstractmethod
    def MutateAds(
        self,
        request: global___MutateAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdsResponse: ...

def add_AdServiceServicer_to_server(
    servicer: AdServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignCriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignCriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignCriterionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignCriterionErrorEnum.CampaignCriterionError.V(0)
        UNKNOWN = CampaignCriterionErrorEnum.CampaignCriterionError.V(1)
        CONCRETE_TYPE_REQUIRED = CampaignCriterionErrorEnum.CampaignCriterionError.V(2)
        INVALID_PLACEMENT_URL = CampaignCriterionErrorEnum.CampaignCriterionError.V(3)
        CANNOT_EXCLUDE_CRITERIA_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(4)
        )
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(5)
        )
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(6)
        )
        CANNOT_TARGET_AND_EXCLUDE = CampaignCriterionErrorEnum.CampaignCriterionError.V(
            7
        )
        TOO_MANY_OPERATIONS = CampaignCriterionErrorEnum.CampaignCriterionError.V(8)
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(9)
        )
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(10)
        )
        CANNOT_ADD_EXISTING_FIELD = CampaignCriterionErrorEnum.CampaignCriterionError.V(
            11
        )
        CANNOT_UPDATE_NEGATIVE_CRITERION = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(12)
        )
    class CampaignCriterionError(metaclass=_CampaignCriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignCriterionErrorEnum.CampaignCriterionError.V(0)
    UNKNOWN = CampaignCriterionErrorEnum.CampaignCriterionError.V(1)
    CONCRETE_TYPE_REQUIRED = CampaignCriterionErrorEnum.CampaignCriterionError.V(2)
    INVALID_PLACEMENT_URL = CampaignCriterionErrorEnum.CampaignCriterionError.V(3)
    CANNOT_EXCLUDE_CRITERIA_TYPE = CampaignCriterionErrorEnum.CampaignCriterionError.V(
        4
    )
    CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(5)
    )
    CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(6)
    )
    CANNOT_TARGET_AND_EXCLUDE = CampaignCriterionErrorEnum.CampaignCriterionError.V(7)
    TOO_MANY_OPERATIONS = CampaignCriterionErrorEnum.CampaignCriterionError.V(8)
    OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(9)
    )
    SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(10)
    )
    CANNOT_ADD_EXISTING_FIELD = CampaignCriterionErrorEnum.CampaignCriterionError.V(11)
    CANNOT_UPDATE_NEGATIVE_CRITERION = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignCriterionErrorEnum = CampaignCriterionErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.access_role_pb2
import google.ads.google_ads.v6.proto.enums.response_content_type_pb2
import google.ads.google_ads.v6.proto.resources.customer_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetCustomerRequest = GetCustomerRequest

class MutateCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    RESPONSE_CONTENT_TYPE_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    validate_only: builtins.bool = ...
    response_content_type: google.ads.google_ads.v6.proto.enums.response_content_type_pb2.ResponseContentTypeEnum.ResponseContentType.V = (
        ...
    )
    @property
    def operation(self) -> global___CustomerOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[global___CustomerOperation] = ...,
        validate_only: builtins.bool = ...,
        response_content_type: google.ads.google_ads.v6.proto.enums.response_content_type_pb2.ResponseContentTypeEnum.ResponseContentType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operation",
            b"operation",
            "response_content_type",
            b"response_content_type",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___MutateCustomerRequest = MutateCustomerRequest

class CreateCustomerClientRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    CUSTOMER_CLIENT_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    ACCESS_ROLE_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    email_address: typing.Text = ...
    access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = (
        ...
    )
    @property
    def customer_client(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.customer_pb2.Customer: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        customer_client: typing.Optional[
            google.ads.google_ads.v6.proto.resources.customer_pb2.Customer
        ] = ...,
        email_address: typing.Text = ...,
        access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_email_address",
            b"_email_address",
            "customer_client",
            b"customer_client",
            "email_address",
            b"email_address",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_email_address",
            b"_email_address",
            "access_role",
            b"access_role",
            "customer_client",
            b"customer_client",
            "customer_id",
            b"customer_id",
            "email_address",
            b"email_address",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_email_address", b"_email_address"],
    ) -> typing_extensions.Literal["email_address"]: ...

global___CreateCustomerClientRequest = CreateCustomerClientRequest

class CustomerOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPDATE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def update(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.customer_pb2.Customer: ...
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        update: typing.Optional[
            google.ads.google_ads.v6.proto.resources.customer_pb2.Customer
        ] = ...,
        update_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "update", b"update", "update_mask", b"update_mask"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "update", b"update", "update_mask", b"update_mask"
        ],
    ) -> None: ...

global___CustomerOperation = CustomerOperation

class CreateCustomerClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    INVITATION_LINK_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    invitation_link: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        invitation_link: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "invitation_link", b"invitation_link", "resource_name", b"resource_name"
        ],
    ) -> None: ...

global___CreateCustomerClientResponse = CreateCustomerClientResponse

class MutateCustomerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateCustomerResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[global___MutateCustomerResult] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateCustomerResponse = MutateCustomerResponse

class MutateCustomerResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CUSTOMER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def customer(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.customer_pb2.Customer: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        customer: typing.Optional[
            google.ads.google_ads.v6.proto.resources.customer_pb2.Customer
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["customer", b"customer"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer", b"customer", "resource_name", b"resource_name"
        ],
    ) -> None: ...

global___MutateCustomerResult = MutateCustomerResult

class ListAccessibleCustomersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ListAccessibleCustomersRequest = ListAccessibleCustomersRequest

class ListAccessibleCustomersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAMES_FIELD_NUMBER: builtins.int
    resource_names: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        resource_names: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_names", b"resource_names"]
    ) -> None: ...

global___ListAccessibleCustomersResponse = ListAccessibleCustomersResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_audience_view_pb2
import grpc

from .ad_group_audience_view_service_pb2 import *

class AdGroupAudienceViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupAudienceView(
        self,
        request: global___GetAdGroupAudienceViewRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_audience_view_pb2.AdGroupAudienceView: ...

class AdGroupAudienceViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupAudienceView(
        self,
        request: global___GetAdGroupAudienceViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_audience_view_pb2.AdGroupAudienceView: ...

def add_AdGroupAudienceViewServiceServicer_to_server(
    servicer: AdGroupAudienceViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.click_location_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    GCLID_FIELD_NUMBER: builtins.int
    AREA_OF_INTEREST_FIELD_NUMBER: builtins.int
    LOCATION_OF_PRESENCE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_FIELD_NUMBER: builtins.int
    CAMPAIGN_LOCATION_TARGET_FIELD_NUMBER: builtins.int
    USER_LIST_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    gclid: typing.Text = ...
    page_number: builtins.int = ...
    ad_group_ad: typing.Text = ...
    campaign_location_target: typing.Text = ...
    user_list: typing.Text = ...
    @property
    def area_of_interest(
        self,
    ) -> google.ads.google_ads.v6.proto.common.click_location_pb2.ClickLocation: ...
    @property
    def location_of_presence(
        self,
    ) -> google.ads.google_ads.v6.proto.common.click_location_pb2.ClickLocation: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        gclid: typing.Text = ...,
        area_of_interest: typing.Optional[
            google.ads.google_ads.v6.proto.common.click_location_pb2.ClickLocation
        ] = ...,
        location_of_presence: typing.Optional[
            google.ads.google_ads.v6.proto.common.click_location_pb2.ClickLocation
        ] = ...,
        page_number: builtins.int = ...,
        ad_group_ad: typing.Text = ...,
        campaign_location_target: typing.Text = ...,
        user_list: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_campaign_location_target",
            b"_campaign_location_target",
            "_gclid",
            b"_gclid",
            "_page_number",
            b"_page_number",
            "_user_list",
            b"_user_list",
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "campaign_location_target",
            b"campaign_location_target",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
            "user_list",
            b"user_list",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_campaign_location_target",
            b"_campaign_location_target",
            "_gclid",
            b"_gclid",
            "_page_number",
            b"_page_number",
            "_user_list",
            b"_user_list",
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "campaign_location_target",
            b"campaign_location_target",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
            "resource_name",
            b"resource_name",
            "user_list",
            b"user_list",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group_ad", b"_ad_group_ad"]
    ) -> typing_extensions.Literal["ad_group_ad"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_campaign_location_target", b"_campaign_location_target"
        ],
    ) -> typing_extensions.Literal["campaign_location_target"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gclid", b"_gclid"]
    ) -> typing_extensions.Literal["gclid"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_page_number", b"_page_number"]
    ) -> typing_extensions.Literal["page_number"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_user_list", b"_user_list"]
    ) -> typing_extensions.Literal["user_list"]: ...

global___ClickView = ClickView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MatchingFunctionOperatorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MatchingFunctionOperator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MatchingFunctionOperator.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(0)
        UNKNOWN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(1)
        IN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(2)
        IDENTITY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(3)
        EQUALS = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(4)
        AND = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(5)
        CONTAINS_ANY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(6)
    class MatchingFunctionOperator(metaclass=_MatchingFunctionOperator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(0)
    UNKNOWN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(1)
    IN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(2)
    IDENTITY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(3)
    EQUALS = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(4)
    AND = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(5)
    CONTAINS_ANY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(6)
    def __init__(
        self,
    ) -> None: ...

global___MatchingFunctionOperatorEnum = MatchingFunctionOperatorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListStringRuleItemOperatorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListStringRuleItemOperator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserListStringRuleItemOperator.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(0)
        )
        UNKNOWN = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(1)
        CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
            2
        )
        EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(3)
        STARTS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(4)
        )
        ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
            5
        )
        NOT_EQUALS = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(6)
        )
        NOT_CONTAINS = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(7)
        )
        NOT_STARTS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(8)
        )
        NOT_ENDS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(9)
        )
    class UserListStringRuleItemOperator(metaclass=_UserListStringRuleItemOperator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(0)
    UNKNOWN = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(1)
    CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(2)
    EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(3)
    STARTS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(4)
    ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(5)
    NOT_EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(6)
    NOT_CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
        7
    )
    NOT_STARTS_WITH = (
        UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(8)
    )
    NOT_ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
        9
    )
    def __init__(
        self,
    ) -> None: ...

global___UserListStringRuleItemOperatorEnum = UserListStringRuleItemOperatorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CITY_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    METRO_FIELD_NUMBER: builtins.int
    MOST_SPECIFIC_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def city(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def metro(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def most_specific(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def region(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        city: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        metro: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        most_specific: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        region: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> None: ...

global___ClickLocation = ClickLocation
